==> pmml-model-1.4.15-sources.jar: org/dmg/pmml/bayesian_network/PMMLAttributes.java <==

package org.dmg.pmml.bayesian_network;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field BAYESIANNETWORKMODEL_MODELNAME = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "modelName");
    Field BAYESIANNETWORKMODEL_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "miningFunction");
    Field BAYESIANNETWORKMODEL_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "algorithmName");
    Field BAYESIANNETWORKMODEL_SCORABLE = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "scorable");
    Field BAYESIANNETWORKMODEL_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "mathContext");
    Field CONTINUOUSCONDITIONALPROBABILITY_COUNT = org.jpmml.model.ReflectionUtil.getField(ContinuousConditionalProbability.class, "count");
    Field CONTINUOUSNODE_NAME = org.jpmml.model.ReflectionUtil.getField(ContinuousNode.class, "name");
    Field CONTINUOUSNODE_COUNT = org.jpmml.model.ReflectionUtil.getField(ContinuousNode.class, "count");
    Field DISCRETECONDITIONALPROBABILITY_COUNT = org.jpmml.model.ReflectionUtil.getField(DiscreteConditionalProbability.class, "count");
    Field DISCRETENODE_NAME = org.jpmml.model.ReflectionUtil.getField(DiscreteNode.class, "name");
    Field DISCRETENODE_COUNT = org.jpmml.model.ReflectionUtil.getField(DiscreteNode.class, "count");
    Field PARENTVALUE_PARENT = org.jpmml.model.ReflectionUtil.getField(ParentValue.class, "parent");
    Field PARENTVALUE_VALUE = org.jpmml.model.ReflectionUtil.getField(ParentValue.class, "value");
    Field VALUEPROBABILITY_VALUE = org.jpmml.model.ReflectionUtil.getField(ValueProbability.class, "value");
    Field VALUEPROBABILITY_PROBABILITY = org.jpmml.model.ReflectionUtil.getField(ValueProbability.class, "probability");

}

==> pmml-model-1.5.16-sources.jar: org/dmg/pmml/bayesian_network/PMMLAttributes.java <==

package org.dmg.pmml.bayesian_network;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field BAYESIANNETWORKMODEL_MODELNAME = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "modelName");
    Field BAYESIANNETWORKMODEL_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "miningFunction");
    Field BAYESIANNETWORKMODEL_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "algorithmName");
    Field BAYESIANNETWORKMODEL_MODELTYPE = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "modelType");
    Field BAYESIANNETWORKMODEL_INFERENCEMETHOD = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "inferenceMethod");
    Field BAYESIANNETWORKMODEL_SCORABLE = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "scorable");
    Field BAYESIANNETWORKMODEL_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(BayesianNetworkModel.class, "mathContext");
    Field CONTINUOUSCONDITIONALPROBABILITY_COUNT = org.jpmml.model.ReflectionUtil.getField(ContinuousConditionalProbability.class, "count");
    Field CONTINUOUSNODE_NAME = org.jpmml.model.ReflectionUtil.getField(ContinuousNode.class, "name");
    Field CONTINUOUSNODE_COUNT = org.jpmml.model.ReflectionUtil.getField(ContinuousNode.class, "count");
    Field DISCRETECONDITIONALPROBABILITY_COUNT = org.jpmml.model.ReflectionUtil.getField(DiscreteConditionalProbability.class, "count");
    Field DISCRETENODE_NAME = org.jpmml.model.ReflectionUtil.getField(DiscreteNode.class, "name");
    Field DISCRETENODE_COUNT = org.jpmml.model.ReflectionUtil.getField(DiscreteNode.class, "count");
    Field PARENTVALUE_PARENT = org.jpmml.model.ReflectionUtil.getField(ParentValue.class, "parent");
    Field PARENTVALUE_VALUE = org.jpmml.model.ReflectionUtil.getField(ParentValue.class, "value");
    Field VALUEPROBABILITY_VALUE = org.jpmml.model.ReflectionUtil.getField(ValueProbability.class, "value");
    Field VALUEPROBABILITY_PROBABILITY = org.jpmml.model.ReflectionUtil.getField(ValueProbability.class, "probability");

}
